@@ -3,7 +3,7 @@
 module Dry
   class Struct
     # Raised when given input doesn't conform schema and constructor type
-    Error = Class.new(TypeError)
+    Error = Class.new(::Dry::Types::CoercionError)
 
     # Raised when defining duplicate attributes
     class RepeatedAttributeError < ::ArgumentError
@@ -16,8 +16,8 @@ module Dry
 
     # Raised when a struct doesn't have an attribute
     class MissingAttributeError < ::KeyError
-      def initialize(key)
-        super("Missing attribute: #{key.inspect}")
+      def initialize(attribute:, klass:)
+        super("Missing attribute: #{attribute.inspect} on #{klass}")
       end
     end
 
