@@ -18,13 +18,20 @@ $VERBOSE = true
 
 require "dry-struct"
 
-begin
-  require "pry"
-  require "pry-byebug"
+%w[debug pry-byebug pry byebug].each do |gem|
+  require gem
 rescue LoadError
+  nil
+else
+  break
 end
 
-Dir[Pathname(__dir__).join("shared/*.rb")].sort.each(&method(:require))
+Dir[Pathname(__dir__).join("shared/*.rb")].each(&method(:require))
+
+Warning.ignore(/rspec-expectations/)
+Warning.ignore(/super_diff/)
+Warning.process { raise _1 }
+
 require "dry/types/spec/types"
 
 RSpec.configure do |config|
